# numtostr_rus is simple python number to russian string converter



## Examples:

```pycon
>>> from numtostr_rus import converter as numtostr_rus
>>> str_rus = numtostr_rus(
...     42
... )  # '42'
```
